summaryrefslogtreecommitdiff
path: root/worker/tests/ftp.rb
diff options
context:
space:
mode:
authorSteve Kemp <steve@steve.org.uk>2012-11-13 13:08:35 +0000
committerSteve Kemp <steve@steve.org.uk>2012-11-13 13:08:35 +0000
commitab876665a2cf25b1bf557ea7d6cd9ff7e7923db6 (patch)
tree6b6affb2de6d84f3935a5cf5d6b2ce59f846830e /worker/tests/ftp.rb
parent37b701fc0c7002e2d84f2d61bd9c57085c8b9542 (diff)
Renamed 'get_details()' to 'error()'.
Diffstat (limited to 'worker/tests/ftp.rb')
-rwxr-xr-xworker/tests/ftp.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/worker/tests/ftp.rb b/worker/tests/ftp.rb
index 9879c90..30b89d5 100755
--- a/worker/tests/ftp.rb
+++ b/worker/tests/ftp.rb
@@ -38,7 +38,7 @@ class FTPTest
#
# Return "false" on failure.
#
# If the test fails the details should be retrieved from "get_details".
#
def run_test
@@ -119,7 +119,7 @@ if __FILE__ == $0 then
puts "TEST OK"
else
puts "TEST FAILED"
- puts tst.get_details()
+ puts tst.error()
end
end
@@ -38,7 +38,7 @@ class FTPTest
# Return "false" on failure.
#
- # If the test fails the details should be retrieved from "get_details".
+ # If the test fails the details should be retrieved from "error()".
#
def run_test